#comment out if not pre-release
#define prel     rc3

%define rel     2

Name:           xdg-utils
Version:        1.2.1
Release:        %mkrel %{?prel:0.%prel.}%{rel}
Summary:        Interfaces and Tools for easy integration with the free desktop configuration
License:        MIT
Url:            https://www.freedesktop.org/wiki/Software/xdg-utils/
Group:          System/Base
Source0:        https://gitlab.freedesktop.org/xdg/xdg-utils/-/archive/v%{version}/%{name}-v%{version}%{?prel:-%prel}.tar.gz
Patch0:         xdg-utils-1.2.1-email_loop.patch
Patch1:         xdg-utils-1.2.1-email_silent_errors.patch
#squidf: don't open a pop-up with kdialog for url-scheme-handler error with XFCE
#       this issue is created by Patch0
Patch3:         xdg-utils-1.1.3-silence-dialog-url-scheme-handler-xfce.patch
# Fix for MGA #15286
# So chromium-browser won't put a dialog on LXDE (and other unrecognised
# desktop environments) when it's not the default browser.
Patch8:         xdg-utils-1.1.0-rc3-silence-dialog-with-chromium-browser-on-lxde.patch
# https://gitlab.freedesktop.org/xdg/xdg-utils/-/issues/177
# CVE-2020-27748
Patch10:	0001-xdg-email-remove-attachment-handling-from-mailto.patch

BuildArch:      noarch
BuildRequires:  libxslt-proc
BuildRequires:  gawk
BuildRequires:  xmlto-notex
BuildRequires:  docbook-dtd412-xml
BuildRequires:  docbook-style-xsl
Requires:       desktop-file-utils
Requires:       xprop
Requires:       xset

%description
The %{name} package is a set of simple scripts that provide basic
desktop integration functions for any Free Desktop, such as Linux.

This version of xdg-utils contains the following commands:
xdg-desktop-menu:       command line tool for (un)installing
                        desktop menu items
xdg-desktop-icon:       command line tool for (un)installing
                        icons to the desktop
xdg-mime:               command line tool for querying information
                        about file type handling and adding
                        descriptions for new file types
xdg-icon-resource:      command line tool for (un)installing icon resources
xdg-open:               opens a file or URL in the user's preferred
                        application
xdg-email:              command line tool for sending mail using the user's
                        preferred e-mail composer
xdg-screensaver:        command line tool for controlling the screensaver
xdg-settings:           get various settings from the desktop environment


%files
%doc README.md TODO RELEASE_NOTES
%{_bindir}/xdg-desktop-icon
%{_bindir}/xdg-desktop-menu
%{_bindir}/xdg-email
%{_bindir}/xdg-icon-resource
%{_bindir}/xdg-mime
%{_bindir}/xdg-open
%{_bindir}/xdg-screensaver
%{_bindir}/xdg-settings
%{_mandir}/man1/xdg-desktop-icon.*
%{_mandir}/man1/xdg-desktop-menu.*
%{_mandir}/man1/xdg-email.*
%{_mandir}/man1/xdg-icon-resource.*
%{_mandir}/man1/xdg-mime.*
%{_mandir}/man1/xdg-open.*
%{_mandir}/man1/xdg-screensaver.*
%{_mandir}/man1/xdg-settings.*

#-------------------------------------------------------------------------------#


%prep
%autosetup -p1 -n %{name}-v%{version}%{?prel:-%prel}

%build
%configure
%make_build
%make_build -C scripts

%install
%make_install


%changelog
* Fri Mar 08 2024 daviddavid <daviddavid> 1.2.1-2.mga10
+ Revision: 2048765
- fix a typo (missing 'fi') in email_silent_errors patch

* Fri Mar 08 2024 daviddavid <daviddavid> 1.2.1-1.mga10
+ Revision: 2048534
- new version: 1.2.1 ((mga#32949 thanks to Aurelian R)
- remove merged upstream patches
- rediff email-remove-attachment-handling-from-mailto, email_loop
  and email_silent_errors patches

* Wed May 03 2023 daviddavid <daviddavid> 1.1.3-10.mga9
+ Revision: 1955716
- add patch to use `grep -E` instead of deprecated `egrep`
  * https://gitlab.freedesktop.org/xdg/xdg-utils/-/merge_requests/44

* Mon Jan 02 2023 squidf <squidf> 1.1.3-9.mga9
+ Revision: 1929244
+ rebuild (emptylog)

* Mon Jan 02 2023 squidf <squidf> 1.1.3-8.1.mga9
+ Revision: 1929223
- Fix dialog pop-up with XFCE for url-scheme-handler error (mga#31293)

* Wed Mar 23 2022 umeabot <umeabot> 1.1.3-8.mga9
+ Revision: 1820725
- Mageia 9 Mass Rebuild

* Wed Jul 07 2021 luigiwalser <luigiwalser> 1.1.3-7.mga9
+ Revision: 1735137
- re-add CVE-2020-27748 patch for now

* Tue Jul 06 2021 luigiwalser <luigiwalser> 1.1.3-6.mga9
+ Revision: 1735011
- revert CVE-2020-27748 due to regressions (mga#28086)
- remove xdg-su from description (incorrect and not shipped in package)
- add latest upstream bug fixes

* Sun Nov 29 2020 wally <wally> 1.1.3-5.mga8
+ Revision: 1650290
- add patch to fix CVE-2020-27748 (mga#27688)

* Wed Feb 12 2020 umeabot <umeabot> 1.1.3-4.mga8
+ Revision: 1508268
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Sep 21 2018 umeabot <umeabot> 1.1.3-3.mga7
+ Revision: 1292159
- Mageia 7 Mass Rebuild

* Fri Jun 08 2018 wally <wally> 1.1.3-2.mga7
+ Revision: 1235401
- backport upstream patch for better pcmanfm check

* Tue May 22 2018 shlomif <shlomif> 1.1.3-1.mga7
+ Revision: 1231517
- New version 1.1.3

* Wed Nov 08 2017 wally <wally> 1.1.2-2.mga7
+ Revision: 1176597
- add patch to fix xdg-open and opening local files in LXQt (mga#21992)

* Tue May 23 2017 luigiwalser <luigiwalser> 1.1.2-1.mga6
+ Revision: 1104172
- 1.1.2

* Sat Feb 20 2016 umeabot <umeabot> 1.1.1-2.mga6
+ Revision: 971716
- Mageia 6 Mass Rebuild

* Sat Oct 17 2015 wally <wally> 1.1.1-1.mga6
+ Revision: 892384
- new version 1.1.1
- drop patches from upstream
- rediff others if needed

* Fri Oct 16 2015 blino <blino> 1.1.0-0.0.rc3.6.mga6
+ Revision: 891964
- make the package noarch (bins are shell scripts, not dependant on arch)

* Mon Feb 16 2015 shlomif <shlomif> 1.1.0-0.0.rc3.5.mga5
+ Revision: 815198
- Fix for MGA #15286

* Mon Jan 19 2015 wally <wally> 1.1.0-0.0.rc3.4.mga5
+ Revision: 811494
- add patches from upstream
  * dereference symlinks when using mimetype or file (fdo#39923)
  * change screensaver_freedesktop's interpretation of GetActive (fdo#29859)
  * improve command injection vulnerability fix (CVE-2014-9622, mga#14932, fdo#66670)

* Mon Jan 05 2015 wally <wally> 1.1.0-0.0.rc3.3.mga5
+ Revision: 808699
- add patch from upstream git to improve screensaver handling in Xfce (fdo#80089)
- another try to fix command injection vulnerability (CVE-2014-9622, mga#14932, fdo#66670)

* Sun Jan 04 2015 wally <wally> 1.1.0-0.0.rc3.2.mga5
+ Revision: 808354
- add patch from upstream bugzilla to fix command injection vulnerability (CVE-2014-9622, mga#14932, fdo#66670)

* Sat Jan 03 2015 wally <wally> 1.1.0-0.0.rc3.1.mga5
+ Revision: 808318
- new version 1.1.0 rc3
- add some %%doc files
- rediff patches

* Wed Oct 15 2014 umeabot <umeabot> 1.1.0-0.0.git20121008.6.mga5
+ Revision: 748885
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.1.0-0.0.git20121008.5.mga5
+ Revision: 690581
- Mageia 5 Mass Rebuild

* Sat May 03 2014 shlomif <shlomif> 1.1.0-0.0.git20121008.4.mga5
+ Revision: 619761
- Fix too long summary
- Fix mixed tabs and spaces in the .spec
- Remove trailing space
- Add patch to inhibit screensaver correctly (mga#7848)

* Fri Oct 18 2013 umeabot <umeabot> 1.1.0-0.0.git20121008.3.mga4
+ Revision: 520519
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 1.1.0-0.0.git20121008.2.mga3
+ Revision: 386716
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Oct 27 2012 wally <wally> 1.1.0-0.0.git20121008.1.mga3
+ Revision: 310705
- use latest git snapshot

* Wed Feb 15 2012 ovitters <ovitters> 1.1.0-0.rc1.2.mga2
+ Revision: 209257
- clean spec

* Fri Jan 07 2011 dmorgan <dmorgan> 1.1.0-0.rc1.1.mga1
+ Revision: 209
- imported package xdg-utils


* Thu Feb 25 2010 Thierry Vignaud <tv@mandriva.org> 1.0.3-0.20100204.3mdv2011.0
+ Revision: 511100
- add missing requires on xset (#55101)

* Thu Feb 04 2010 Emmanuel Andry <eandry@mandriva.org> 1.0.3-0.20100204.2mdv2010.1
+ Revision: 500941
- readd accidentally removed (rediffed) patch 1
- renumber actual p1 to p2

* Thu Feb 04 2010 Emmanuel Andry <eandry@mandriva.org> 1.0.3-0.20100204.1mdv2010.1
+ Revision: 500813
- BR docbook-dtd412-xml
- new cvs snapshot (mainly kde4 fixes)
- use make
- diff patch to enable xdg-terminal
- use cvs switch

* Tue Dec 15 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.2-16mdv2010.1
+ Revision: 478865
- P2: Silent errors

* Tue Dec 15 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.2-15mdv2010.1
+ Revision: 478814
- Add back xdg-utils-1.0.2-email_loop.patch removed by error

* Sun Sep 20 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.2-14mdv2010.0
+ Revision: 444793
- Update to xdg-utils trunk ( fix a lot of kde4 issues)

* Sat Sep 19 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.2-13mdv2010.0
+ Revision: 444763
- Add patch7 : Fix kde4 support in xdg-open

* Sat Mar 07 2009 Antoine Ginies <aginies@mandriva.com> 1.0.2-12mdv2009.1
+ Revision: 351208
- rebuild

* Wed Sep 03 2008 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.2-11mdv2009.0
+ Revision: 279353
- typo typo typo ...

* Mon Sep 01 2008 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.2-10mdv2009.0
+ Revision: 278060
- Fix typo in xdg-utils-1.0.2-detect-KDE4.patch

* Sun Aug 31 2008 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.2-9mdv2009.0
+ Revision: 277921
- Fix sed
- Move sed out of %%post
- Remove broken patch7

* Sat Aug 30 2008 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.2-8mdv2009.0
+ Revision: 277599
- [BUGFIX] harcode path of kmailservice under kde4 if not kde3 one will be used (#41819)
- [BUGFIX] Fix  kfmclient_fix_exit_code under KDE4 (tks to Luc Menut )(Bug #41818)
- Start to support kde4

* Wed Jun 18 2008 Thierry Vignaud <tv@mandriva.org> 1.0.2-6mdv2009.0
+ Revision: 226028
- rebuild
- fix description-line-too-long

* Fri Feb 01 2008 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.2-5mdv2008.1
+ Revision: 161209
- Fix CVE-2008-0386 (Bug #37380)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Oct 27 2007 Pascal Terjan <pterjan@mandriva.org> 1.0.2-4mdv2008.1
+ Revision: 102592
- Make MIME type detection under GNOME more robust (upstream #12818)

* Tue Aug 28 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.0.2-3mdv2008.0
+ Revision: 72822
- Enhance error reporting for xdg-email by reporting via zenity/kdialog when possible.
- Fixes FF/xdg-email looping. Closes: #32535

  + Thierry Vignaud <tv@mandriva.org>
    - fix man pages extension

  + Nicolas Lécureuil <nlecureuil@mandriva.com>
    - Fix Requries (#32123)

* Tue Jun 26 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.2-1mdv2008.0
+ Revision: 44254
- new version
- spec file clean


* Tue Feb 20 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.1-3mdv2007.0
+ Revision: 123080
-Drop test-suite subpackage, not working correctly
-Patch0: fix xdg-mime default applications (Mdv bug #28711)

* Thu Nov 30 2006 Laurent Montel <lmontel@mandriva.com> 1.0.1-2mdv2007.1
+ Revision: 89361
- Increase release
- Separate test suite file into own package

* Wed Nov 15 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1.0.1-1mdv2007.1
+ Revision: 84271
- Fix spec
- Use good tarball
- New release 1.0.1
- xdg-utils-1.0-0.rc1.1mdv2007.0
- xdg-utils-1.0-0.beta3.1mdv2007.0
- Remove Patch0: Merged upstream
- Fix patch 0: thanks chty for your tests
- Use right release
- Increase release
- Fix wrong requires (thanks chty)

* Mon Aug 07 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1.0-0.beta1.3mdv2007.0
+ Revision: 53417
- Increase release
- Add Mandriva in the result of the test suite
  before :  distribution: distribution unknown
  now    :  distribution: Mandriva Linux 2007.0
- Package the test-suite too
- Add Requires

* Sun Aug 06 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1.0-0.beta1.2mdv2007.0
+ Revision: 53194
-1.0 beta2
- Fix description
- Increase release
- import xdg-utils-1.0-0.beta1.0mdv2007.0
